@@ -19,7 +19,7 @@ BINANCE = "BINANCE"
 IDENTIFIER_QUERY_PARAM = "identifier"
 TARGET_SYMBOL_QUERY_PARAM = "target_symbol"
 TRADING_SYMBOL_QUERY_PARAM = "trading_symbol"
-ORDER_SIDE_QUERY_PARAM = "order_side"
+ORDER_SIDE_QUERY_PARAM = "side"
 STATUS_QUERY_PARAM = "status"
 POSITION_SYMBOL_QUERY_PARAM = "position"
 SYMBOL_QUERY_PARAM = "symbol"
