@@ -24,14 +24,20 @@ from investing_algorithm_framework.core.models.position import Position
 from investing_algorithm_framework.core.models.time_frame import TimeFrame
 from investing_algorithm_framework.core.models.time_intervals import \
     TimeInterval
+from investing_algorithm_framework.core.models.sql_lite import \
+    SQLLitePosition, SQLLiteOrder, SQLLitePortfolio
 from investing_algorithm_framework.core.models.snapshots import \
-    PositionSnapshot, PortfolioSnapshot
+    PositionSnapshot, PortfolioSnapshot, SQLLitePortfolioSnapshot, \
+    SQLLiteAssetPrice, SQLLitePositionSnapshot, SQLLiteAssetPriceHistory, \
+    AssetPrice, AssetPriceHistory
 
 __all__ = [
     "db",
     "Portfolio",
     "Position",
+    "SQLLitePosition",
     'Order',
+    "SQLLiteOrder",
     "OrderType",
     'OrderSide',
     "TimeUnit",
@@ -42,5 +48,12 @@ __all__ = [
     "TimeInterval",
     "PortfolioSnapshot",
     "PositionSnapshot",
-    "PerformanceMetric"
+    "PerformanceMetric",
+    "SQLLitePortfolio",
+    "SQLLitePortfolioSnapshot",
+    "SQLLitePositionSnapshot",
+    "AssetPrice",
+    "AssetPriceHistory",
+    "SQLLiteAssetPrice",
+    "SQLLiteAssetPriceHistory"
 ]
