@@ -13,7 +13,8 @@ def get_main_version(version=None):
 
 def get_complete_version(version=None):
     """
-    Return a tuple of the investing algorithm framework  version. If version argument is non-empty,
+    Return a tuple of the investing algorithm framework  version. If version
+    argument is non-empty,
     check for correctness of the tuple provided.
     """
     if version is None:
